summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/factories/stdwidgetfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/factories/stdwidgetfactory.cpp')
-rw-r--r--kexi/formeditor/factories/stdwidgetfactory.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kexi/formeditor/factories/stdwidgetfactory.cpp b/kexi/formeditor/factories/stdwidgetfactory.cpp
index 2607fcca..24827e13 100644
--- a/kexi/formeditor/factories/stdwidgetfactory.cpp
+++ b/kexi/formeditor/factories/stdwidgetfactory.cpp
@@ -431,13 +431,13 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
w = new KProgress(p, n);
else if(c == "KDateWidget")
- w = new KDateWidget(TQDate::currentDate(), p, n);
+ w = new KDateWidget(TQDate::tqcurrentDate(), p, n);
else if(c == "KTimeWidget")
w = new KTimeWidget(TQTime::currentTime(), p, n);
else if(c == "KDateTimeWidget")
- w = new KDateTimeWidget(TQDateTime::currentDateTime(), p, n);
+ w = new KDateTimeWidget(TQDateTime::tqcurrentDateTime(), p, n);
else if(c == "Line")
w = new Line(options & WidgetFactory::VerticalOrientation ? Qt::Vertical : Qt::Horizontal, p, n);
@@ -492,7 +492,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
if(classname == "KLineEdit")
{
KLineEdit *lineedit = static_cast<KLineEdit*>(w);
- createEditor(classname, lineedit->text(), lineedit, container, lineedit->geometry(), lineedit->alignment(), true);
+ createEditor(classname, lineedit->text(), lineedit, container, lineedit->tqgeometry(), lineedit->tqalignment(), true);
return true;
}
else if(classname == TQLABEL_OBJECT_NAME_STRING)
@@ -505,7 +505,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
editText();
}
else
- createEditor(classname, label->text(), label, container, label->geometry(), label->alignment());
+ createEditor(classname, label->text(), label, container, label->tqgeometry(), label->tqalignment());
return true;
}
else if(classname == "KPushButton")
@@ -531,7 +531,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
else if(classname == TQCHECKBOX_OBJECT_NAME_STRING)
{
TQCheckBox *check = static_cast<TQCheckBox*>(w);
- //TQRect r(check->geometry());
+ //TQRect r(check->tqgeometry());
//r.setX(r.x() + 20);
TQRect r = w->tqstyle().subRect(TQStyle::SR_CheckBoxContents, w);
TQRect editorRect = TQRect(check->x() + r.x(), check->y() + r.y(), r.width(), r.height());
@@ -605,13 +605,13 @@ StdWidgetFactory::changeText(const TQString &text)
else
changeProperty("text", text, m_container->form());
/* By-hand method not needed as sizeHint() can do that for us
TQFontMetrics fm = w->fontMetrics();
TQSize s(fm.width( text ), fm.height());
int width;
if(n == TQLABEL_OBJECT_NAME_STRING) // labels are resized to fit the text
{
- w->resize(w->sizeHint());
+ w->resize(w->tqsizeHint());
WidgetFactory::m_editor->resize(w->size());
return;
}
@@ -624,7 +624,7 @@ StdWidgetFactory::changeText(const TQString &text)
width = w->style().sizeFromContents( TQStyle::CT_RadioButton, w, s).width();
else
return;
- int width = w->sizeHint().width();*/
+ int width = w->tqsizeHint().width();*/
#if 0 //not needed here, size hint is used on creation in InsertWidgetCommand::execute()
if(w->width() < width)
@@ -860,7 +860,7 @@ StdWidgetFactory::isPropertyVisibleInternal(const TQCString &classname,
}
else if(classname == "KexiPictureLabel")
{
- if((property == "text") || (property == "indent") || (property == "textFormat") || (property == "font") || (property == "alignment"))
+ if((property == "text") || (property == "indent") || (property == "textFormat") || (property == "font") || (property == "tqalignment"))
return false;
}
else if(classname == TQLABEL_OBJECT_NAME_STRING)
@@ -956,7 +956,7 @@ StdWidgetFactory::editText()
}
if(classname == TQLABEL_OBJECT_NAME_STRING)
- widget()->resize(widget()->sizeHint());
+ widget()->resize(widget()->tqsizeHint());
}
void
@@ -605,13 +605,13 @@ StdWidgetFactory::changeText(const TQString &text)
else
changeProperty("text", text, m_container->form());
- /* By-hand method not needed as sizeHint() can do that for us
+ /* By-hand method not needed as tqsizeHint() can do that for us
TQFontMetrics fm = w->fontMetrics();
TQSize s(fm.width( text ), fm.height());